==> mx-conky_21.7.011.tar.xz: 64/translations/mx-conky_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="48"/>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>MX Conky</source>
        <translation>MX Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;This app enables detailed changes to the active conky. It supplements Conky Manager, which should be used for basic settings.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;Ta aplikacija omgoča podrobno spreminjanje aktivnega conkyja. Nadomesti Conky urejevalnik, ki se uporablja za osnovne nastavitve.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Launch</source>
        <translation>Izvedi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="85"/>
        <source>Run</source>
        <translation>Zaženi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>Undo</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Conky Name</source>
        <translation>Conky ime</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="211"/>
        <source>Conky Manager</source>
        <translation>Upravljalnik za Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>Drag</source>
        <translation>Povleci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>To Resize</source>
        <translation>za spreminjanje velikosti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>+ Left Click</source>
        <translation>+ levi klik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>To Move</source>
        <translation>za premikanje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="288"/>
        <source>+ Right Click</source>
        <translation>+ desni klik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="295"/>
        <source>NOTE: changes last only for the current session</source>
        <translation>OPOMBA: spremembe veljajo le za trenutno sejo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>Desktop</source>
        <translation>Namizje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <source>Desktop 1</source>
        <translation>Namizje 1</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <source>All Desktops</source>
        <translation>Vsa namizja</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>Day</source>
        <translation>Dan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="517"/>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Long</source>
        <translation>Dolgi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Abbreviated name, e.g. Tu</source>
        <translation>Skrajšano ime, npr. TO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <location filename="../mainwindow.ui" line="679"/>
        <source>Short</source>
        <translation>Kratek</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="618"/>
        <source>Month</source>
        <translation>Mesec</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>Abbreviated name, e.g. Oct</source>
        <translation>Skrajšano ime, npr. okt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="732"/>
        <source>Colors</source>
        <translation>Barve</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Default</source>
        <translation>Privzeto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="833"/>
        <location filename="../mainwindow.ui" line="948"/>
        <location filename="../mainwindow.ui" line="1063"/>
        <location filename="../mainwindow.ui" line="1181"/>
        <location filename="../mainwindow.ui" line="1299"/>
        <location filename="../mainwindow.ui" line="1417"/>
        <location filename="../mainwindow.ui" line="1532"/>
        <location filename="../mainwindow.ui" line="1647"/>
        <location filename="../mainwindow.ui" line="1762"/>
        <location filename="../mainwindow.ui" line="1877"/>
        <location filename="../mainwindow.ui" line="1992"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="896"/>
        <source>Color0 </source>
        <translation>Barva0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1011"/>
        <source>Color1 </source>
        <translation>Barva1</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1126"/>
        <source>Color2 </source>
        <translation>Barva2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1244"/>
        <source>Color3 </source>
        <translation>Barva3</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1362"/>
        <source>Color4 </source>
        <translation>Barva4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1480"/>
        <source>Color5</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1595"/>
        <source>Color6</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1710"/>
        <source>Color7</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1825"/>
        <source>Color8</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1940"/>
        <source>Color9</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2048"/>
        <source>About this application</source>
        <translation>O tem programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2051"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2058"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2074"/>
        <source>Display help </source>
        <translation>Prikaži pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2077"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2084"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2132"/>
        <source>Quit application</source>
        <translation>Zapri aplikacijo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2135"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2142"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="509"/>
        <source>About MX Conky</source>
        <translation>O MX Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>GUI program for configuring Conky in MX Linux</source>
        <translation>Grafični vmesnik za konfiguriranje Conkyja v MX Linuxu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="513"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="514"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="515"/>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>Changelog</source>
        <translation>Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="554"/>
        <source>MX Conky Help</source>
        <translation>MX Conky pomoč</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="55"/>
        <location filename="../mainwindow.cpp" line="668"/>
        <source>Select Conky Manager config file</source>
        <translation>Izberi konfiguracijsko datoteko za Conky upravljalnik</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Conky Data Update</source>
        <translation>Posodobi Conky podatke</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>The MX Conky data set has been updated. &lt;p&gt;&lt;p&gt;                                  Copy from the folder where it is located &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;/usr/share/mx-conky-data/themes&lt;/a&gt;                                   whatever you wish to your Home hidden conky folder &lt;a href=&quot;%1/.conky&quot;&gt;~/.conky&lt;/a&gt;.                                   Be careful not to overwrite any conkies you have changed.</source>
        <translation>Nabor podatkov za MX Conky je bil posodobljen. &lt;p&gt;&lt;p&gt;Kar želite, prekopirajte iz mape, kjer se nahaja &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;/usr/share/mx-conky-data/themes&lt;/a&gt;   v vašo skrito mapo v Home &lt;a href=&quot;%1/.conky&quot;&gt;~/.conky&lt;/a&gt;.                                    Pazite, da ne boste prepisali katerega od conkijev, ki ste jih spremenili.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="103"/>
        <location filename="../main.cpp" line="134"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="104"/>
        <source>Could not find conky-manager, please install it before running mx-conky</source>
        <translation>Nisem našel conky-manager. Prosimo, da ga namestite, preden zaženete mx-conky</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="134"/>
        <source>You must run this program as normal user</source>
        <translation>Ta program morate zagnati kot navaden uporabnik</translation>
    </message>
</context>
</TS>

==> mx-conky_22.10.01.tar.xz: 64/translations/mx-conky_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="48"/>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>MX Conky</source>
        <translation>MX Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;This app enables detailed changes to the active conky. It supplements Conky Manager, which should be used for basic settings.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;Ta aplikacija omgoča podrobno spreminjanje aktivnega conkyja. Nadomesti Conky urejevalnik, ki se uporablja za osnovne nastavitve.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Launch</source>
        <translation>Izvedi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="85"/>
        <source>Run</source>
        <translation>Zaženi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>Undo</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Conky Name</source>
        <translation>Conky ime</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="211"/>
        <source>Conky Manager</source>
        <translation>Upravljalnik za Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>Drag</source>
        <translation>Povleci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>To Resize</source>
        <translation>za spreminjanje velikosti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>+ Left Click</source>
        <translation>+ levi klik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>To Move</source>
        <translation>za premikanje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="288"/>
        <source>+ Right Click</source>
        <translation>+ desni klik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="295"/>
        <source>NOTE: changes last only for the current session</source>
        <translation>OPOMBA: spremembe veljajo le za trenutno sejo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>Desktop</source>
        <translation>Namizje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <source>Desktop 1</source>
        <translation>Namizje 1</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <source>All Desktops</source>
        <translation>Vsa namizja</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>Day</source>
        <translation>Dan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="517"/>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Long</source>
        <translation>Dolgi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Abbreviated name, e.g. Tu</source>
        <translation>Skrajšano ime, npr. TO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <location filename="../mainwindow.ui" line="679"/>
        <source>Short</source>
        <translation>Kratek</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="618"/>
        <source>Month</source>
        <translation>Mesec</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>Abbreviated name, e.g. Oct</source>
        <translation>Skrajšano ime, npr. okt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="732"/>
        <source>Colors</source>
        <translation>Barve</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Default</source>
        <translation>Privzeto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="833"/>
        <location filename="../mainwindow.ui" line="948"/>
        <location filename="../mainwindow.ui" line="1063"/>
        <location filename="../mainwindow.ui" line="1181"/>
        <location filename="../mainwindow.ui" line="1299"/>
        <location filename="../mainwindow.ui" line="1417"/>
        <location filename="../mainwindow.ui" line="1532"/>
        <location filename="../mainwindow.ui" line="1647"/>
        <location filename="../mainwindow.ui" line="1762"/>
        <location filename="../mainwindow.ui" line="1877"/>
        <location filename="../mainwindow.ui" line="1992"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="896"/>
        <source>Color0 </source>
        <translation>Barva0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1011"/>
        <source>Color1 </source>
        <translation>Barva1</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1126"/>
        <source>Color2 </source>
        <translation>Barva2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1244"/>
        <source>Color3 </source>
        <translation>Barva3</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1362"/>
        <source>Color4 </source>
        <translation>Barva4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1480"/>
        <source>Color5</source>
        <translation>Barva5</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1595"/>
        <source>Color6</source>
        <translation>Barva6</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1710"/>
        <source>Color7</source>
        <translation>Barva7</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1825"/>
        <source>Color8</source>
        <translation>Barva8</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1940"/>
        <source>Color9</source>
        <translation>Barva9</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2048"/>
        <source>About this application</source>
        <translation>O tem programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2051"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2058"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2074"/>
        <source>Display help </source>
        <translation>Prikaži pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2077"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2084"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2132"/>
        <source>Quit application</source>
        <translation>Zapri aplikacijo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2135"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2142"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="509"/>
        <source>About MX Conky</source>
        <translation>O MX Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>GUI program for configuring Conky in MX Linux</source>
        <translation>Grafični vmesnik za konfiguriranje Conkyja v MX Linuxu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="513"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="514"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="515"/>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>Changelog</source>
        <translation>Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="554"/>
        <source>MX Conky Help</source>
        <translation>MX Conky pomoč</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="55"/>
        <location filename="../mainwindow.cpp" line="668"/>
        <source>Select Conky Manager config file</source>
        <translation>Izberi konfiguracijsko datoteko za Conky upravljalnik</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Conky Data Update</source>
        <translation>Posodobi Conky podatke</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>The MX Conky data set has been updated. &lt;p&gt;&lt;p&gt;                                  Copy from the folder where it is located &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;/usr/share/mx-conky-data/themes&lt;/a&gt;                                   whatever you wish to your Home hidden conky folder &lt;a href=&quot;%1/.conky&quot;&gt;~/.conky&lt;/a&gt;.                                   Be careful not to overwrite any conkies you have changed.</source>
        <translation>Nabor podatkov za MX Conky je bil posodobljen. &lt;p&gt;&lt;p&gt;Kar želite, prekopirajte iz mape, kjer se nahaja &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;/usr/share/mx-conky-data/themes&lt;/a&gt;   v vašo skrito mapo v Home &lt;a href=&quot;%1/.conky&quot;&gt;~/.conky&lt;/a&gt;.                                    Pazite, da ne boste prepisali katerega od conkijev, ki ste jih spremenili.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="103"/>
        <location filename="../main.cpp" line="134"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="104"/>
        <source>Could not find conky-manager, please install it before running mx-conky</source>
        <translation>Nisem našel conky-manager. Prosimo, da ga namestite, preden zaženete mx-conky</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="134"/>
        <source>You must run this program as normal user</source>
        <translation>Ta program morate zagnati kot navaden uporabnik</translation>
    </message>
</context>
</TS>
